<?php

namespace Beo\Career\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Beo\Career\Http\Resources\CareerResource;
use Beo\Career\Http\Resources\CareersCollection;
use Beo\Career\Scopes\JobProfilePublicScope;
use Beo\Career\Models\JobProfile;

class JobProfilePublicController extends BaseController
{

    /**
     * Show job_profile's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = JobProfile::pushScope(new RequestScope())
            ->pushScope(new JobProfilePublicScope())
            ->select('job_profiles.*')
            ->paginate($pageLimit)
            ->withQueryString();

        $data = new JobProfilesCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('career::job_profile.names'))
            ->view('career::public.job_profile.index')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show job_profile.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = JobProfile::findBySlug($slug);
        $data = new JobProfileResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('career::job_profile.name'))
            ->view('career::public.job_profile.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
