<?php

namespace Beo\Career\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Beo\Career\Models\JobProfile;

class JobProfilePolicy
{

    /**
     * Determine if the given user can view the job_profile.
     *
     * @param UserPolicyInterface $authUser
     * @param JobProfile $job_profile
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, JobProfile $job_profile)
    {
        if ($authUser->canDo('career.job_profile.view') && $authUser->isAdmin()) {
            return true;
        }

        return $job_profile->user_id == user_id() && $job_profile->user_type == user_type();
    }

    /**
     * Determine if the given user can create a job_profile.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('career.job_profile.create');
    }

    /**
     * Determine if the given user can update the given job_profile.
     *
     * @param UserPolicyInterface $authUser
     * @param JobProfile $job_profile
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, JobProfile $job_profile)
    {
        if ($authUser->canDo('career.job_profile.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $job_profile->user_id == user_id() && $job_profile->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given job_profile.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, JobProfile $job_profile)
    {
        return $job_profile->user_id == user_id() && $job_profile->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given job_profile.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, JobProfile $job_profile)
    {
        if ($authUser->canDo('career.job_profile.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given job_profile.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, JobProfile $job_profile)
    {
        if ($authUser->canDo('career.job_profile.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
