<?php

namespace Beo\Career\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Beo\Career\Models\Profile;

class ProfilePolicy
{

    /**
     * Determine if the given user can view the profile.
     *
     * @param UserPolicyInterface $authUser
     * @param Profile $profile
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Profile $profile)
    {
        if ($authUser->canDo('career.profile.view') && $authUser->isAdmin()) {
            return true;
        }

        return $profile->user_id == user_id() && $profile->user_type == user_type();
    }

    /**
     * Determine if the given user can create a profile.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('career.profile.create');
    }

    /**
     * Determine if the given user can update the given profile.
     *
     * @param UserPolicyInterface $authUser
     * @param Profile $profile
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Profile $profile)
    {
        if ($authUser->canDo('career.profile.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $profile->user_id == user_id() && $profile->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given profile.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Profile $profile)
    {
        return $profile->user_id == user_id() && $profile->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given profile.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Profile $profile)
    {
        if ($authUser->canDo('career.profile.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given profile.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Profile $profile)
    {
        if ($authUser->canDo('career.profile.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
